class IgConsentManager {
    constructor(config) {
        const _defaults = {
            containerId: "#ig_cookies_container",
            baseCookieName: "cookieconsent_accept_"
        };
        this.config = Object.assign(_defaults, config);
        this.consents = {};
        this.watchers = new Set([]);
        this.cookieBannerElement = document.querySelector(this.config.containerId);
        this.loadConsents();
        // wait for async cookies
        setTimeout(() => {
            this.notify(this.consents);
        }, 0);
    }
    loadConsents() {
        // get json array of categories
        let cookieCategories = this.cookieBannerElement.dataset.categories;
        // parse json to array
        let cookieCategoriesArray = JSON.parse(cookieCategories);
        this.consents = cookieCategoriesArray.reduce((obj, consent) => { obj[consent] = false; return obj; }, {});
        // get site cookies
        let cookies = document.cookie ? document.cookie.split("; ") : [];
        // add true/false to consent
        for (let i = 0; i < cookies.length; i++) {
            if (cookies[i].includes(this.config.baseCookieName)) {
                let parts = cookies[i].split("="),
                    name = parts.shift().split("_").pop(),
                    value = Boolean(parts.pop());
                if (this.consents[name] === false) {
                    this.consents[name] = value;
                }
            }
        }
    }
    watch(watcher) {
        if (!this.watchers.has(watcher)) {
            this.watchers.add(watcher);
        }
        if (watcher.hasOwnProperty('init')) {
            watcher.init(this.consents);
        }
    }
    unwatch(watcher) {
        if (this.watchers.has(watcher)) {
            this.watchers.delete(watcher);
        }
    }
    update() {
        this.loadConsents();
        this.notify(this.consents);
    }
    notify(data) {
        this.watchers.forEach((watcher) => {
            watcher.update(data)
        });
    }
    getConsent(name) {
        return this.consents[name] || false;
    }

}
const igConsentManager = new IgConsentManager();
// add IgConsentManager to window object
window.IgConsentManager = igConsentManager;