(function () {
    let domain = getDomain();
    let cookieCategoriesElement = document.getElementById('ig_cookies_container');
    let cookieCategories = JSON.parse(cookieCategoriesElement.dataset.categories);
    let prefix = '';
    let logPending = false;

    // Ugly but the consent banner is hidden in the code and I need to only get the cookie settings plugin if it is on the page
    if (document.getElementsByClassName('.ig_cookies_settings').length) {
        prefix = '.ig_cookies_settings ';
    }

    if (document.getElementsByClassName('.cookieCategory').length) {
        selectCookieCategories();
    }

    if (!document.getElementsByClassName('.ig_cookies_settings').length && !Cookies.get('cookieconsent_hide')) {
        showCookieConsent();
    }

    document.querySelector('.ig_cookies_needed')?.addEventListener('click', function (e) {
        e.preventDefault();
        removeAllCookies();
        acceptNeededCookies();
        hideCookieConsent();
        logAccept(this);
    });

    document.querySelector('.ig_cookies_all')?.addEventListener('click', function (e) {
        e.preventDefault();
        removeAllCookies();
        acceptAllCookies();
        hideCookieConsent();
        logAccept(this);
    });

    document.querySelector('.ig_cookies_save')?.addEventListener('click', function (e) {
        e.preventDefault();
        removeAllCookies();
        saveCookieSettings();
        hideCookieConsent();
        logAccept(this);
    });

    document.querySelector('.ig_cookies_settings_button').addEventListener('click', function (e) {
        e.preventDefault();
        document.querySelector('#ig_cookies_inner').classList.add('showSettings');
        document.querySelector('.ig-cookie-settings-popup').classList.add('show');
        document.querySelector('.ig-cookie-settings-popup-simple').classList.remove('show');
    });

    setDocHeight();
    window.addEventListener('resize', function () {
        setDocHeight();
    });
    window.addEventListener('orientationchange', function () {
        setDocHeight();
    });

    // Workaround 100vh problem with addressbar in mobile browsers
    function setDocHeight() {
        let height = window.innerHeight / 100;
        document.documentElement.style.setProperty('--vh', height + 'px');
    };

    // Domain namen ermitteln ohne Subdomains für Google Analytics Cookies
    function getDomain() {
        let domain = document.domain;
        let domainArr = domain.split('.');
        while (domainArr.length > 2) {
            domainArr.shift();
            domain = '.' + domainArr.join('.');
        }
        return domain;
    }

    function showCookieConsent() {
        document.querySelector("#ig_cookies_container").style.display = 'block';
        document.querySelector("body").classList.add('ig_cookies');
    }

    function hideCookieConsent() {
        let expires = document.querySelector("#ig_cookies_container").dataset.expires;
        if (!expires) {
            expires = 365;
        }
        Cookies.set('cookieconsent_hide', true, { expires: +expires, path: '/', domain: domain });
        document.querySelector("#ig_cookies_container").style.display = 'none';
        document.querySelector("body").classList.remove('ig_cookies');
    }

    function sendSettingsForm() {
        if (document.querySelector('.ig_cookies_settings')) {
            document.querySelector('.ig_cookies_settings form').submit();
        }
    }

    function removeAllCookies() {
        for (let i = 0; i < cookieCategories.length; i++) {
            let cookieCategory = cookieCategories[i];
            let cookieName = 'cookieconsent_accept_' + cookieCategory;
            Cookies.remove(cookieName);
            callOptOutFunctions(cookieCategory);
        }
    }
    function acceptAllCookies() {
        for (let i = 0; i < cookieCategories.length; i++) {
            let cookieCategory = cookieCategories[i];
            let cookieName = 'cookieconsent_accept_' + cookieCategory;
            let checkboxes = document.querySelectorAll(prefix + '.cookieCategory-' + cookieCategory + ' input[type="checkbox"]');
            checkboxes.forEach(function (checkbox) {
                checkbox.checked = true;
                checkbox.setAttribute('checked', true);
            });
            let expires = document.querySelector("#ig_cookies_container").dataset.expires;
            if (!expires) {
                expires = 365;
            }
            Cookies.set(cookieName, true, { expires: +expires, path: '/', domain: domain });
            callOptInFunctions(cookieCategory);
        }
    }
    function acceptNeededCookies() {
        let expires = document.querySelector("#ig_cookies_container").dataset.expires;
        if (!expires) {
            expires = 365;
        }
        Cookies.set('cookieconsent_accept_needed', true, { expires: +expires, path: '/', domain: domain });
        callOptInFunctions('needed');
    }

    function saveCookieSettings() {
        document.querySelectorAll(prefix + '.cookieCategory input[type="checkbox"]:checked').forEach(function (checkbox) {
            let cookieCategory = checkbox.value;
            let cookieName = 'cookieconsent_accept_' + cookieCategory;
            let expires = document.querySelector("#ig_cookies_container").dataset.expires;
            if (!expires) {
                expires = 365;
            }
            Cookies.set(cookieName, true, { expires: +expires, path: '/', domain: domain });
            callOptInFunctions(cookieCategory);
        });
    }

    function selectCookieCategories() {
        document.querySelectorAll(prefix + '.cookieCategory input[type="checkbox"]').forEach(function (checkbox) {
            let cookieCategory = checkbox.value;
            let cookieName = 'cookieconsent_accept_' + cookieCategory;
            if (Cookies.get(cookieName)) {
                checkbox.checked = true;
                checkbox.setAttribute('checked', true);
                callOptInFunctions(cookieCategory);
            }
        });
    }

    function callOptInFunctions(cookieCategory) {
        if (typeof window.igCookiesOptInFunctions !== 'undefined') {
            let optInFunctionsForCategory = window.igCookiesOptInFunctions[cookieCategory];
            if (typeof optInFunctionsForCategory !== 'undefined') {
                for (let j = 0; j < optInFunctionsForCategory.length; j++) {
                    optInFunctionsForCategory[j]();
                }
            }
        }
    }

    function callOptOutFunctions(cookieCategory) {
        if (typeof window.igCookiesOptOutFunctions !== 'undefined') {
            let optOutFunctionsForCategory = window.igCookiesOptOutFunctions[cookieCategory];
            if (typeof optOutFunctionsForCategory !== 'undefined') {
                for (let j = 0; j < optOutFunctionsForCategory.length; j++) {
                    optOutFunctionsForCategory[j]();
                }
            }
        }
    }

    function logAccept(element) {
        let logUrl = element.dataset.page;
        let categories = [];
        document.querySelectorAll(prefix + '.cookieCategory input[type="checkbox"]:checked').forEach(function (checkbox) {
            categories.push(checkbox.value);
        });

        if (logUrl) {
            if (!logPending) {
                logPending = true;
                let xhr = new XMLHttpRequest();
                xhr.open('POST', logUrl, true);
                xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
                xhr.onreadystatechange = function () {
                    if (xhr.readyState === 4 && xhr.status === 200) {
                        logPending = false;
                        sendSettingsForm();
                    }
                };
                xhr.send('categories=' + encodeURIComponent(JSON.stringify(categories)));
            }
        } else {
            sendSettingsForm();
        }
        if (!window.IgConsentManager) {
            console.log('window.IgConsentManager is not defined. Is plugin.ig_cookies.settings.delayedTags set?');
        } else {
            window.IgConsentManager?.update();
        }
    }
})();